moved some constants
[quix0rs-apt-p2p.git] / const.py
index 1d3ee621b1bd355319085824adaeca1314077ba3..e6ef83200d9f7964ac6ff73d60ec65642d729d53 100644 (file)
--- a/const.py
+++ b/const.py
@@ -4,7 +4,11 @@ reactor = SelectReactor(installSignalHandlers=0)
 from twisted.internet import main
 main.installReactor(reactor)
 
-# how many times a node can fail to respond before it's booted from the routing table
+
+# concurrent xmlrpc calls per find node/value request!
+CONCURRENT_REQS = 3
+
+# how many times in a row a node can fail to respond before it's booted from the routing table
 MAX_FAILURES = 3
 
 # time before expirer starts running
@@ -15,3 +19,6 @@ KE_DELAY = 60 * 60 # 1 hour
 
 # expire entries older than this
 KE_AGE = KEINITIAL_DELAY
+
+# never ping a node more often than this
+MIN_PING_INTERVAL = 60 * 15 # fifteen minutes